@@ -162,6 +162,30 @@ def deltalake_write(
     )
 
 
+def lance_write(
+    child_plan: InProgressPhysicalPlan[PartitionT],
+    base_path: str,
+    mode: str,
+    io_config: IOConfig | None,
+    kwargs: dict | None,
+) -> InProgressPhysicalPlan[PartitionT]:
+    """Write the results of `child_plan` into lance data files described by `write_info`."""
+
+    yield from (
+        step.add_instruction(
+            execution_step.WriteLance(
+                base_path=base_path,
+                mode=mode,
+                io_config=io_config,
+                kwargs=kwargs,
+            ),
+        )
+        if isinstance(step, PartitionTaskBuilder)
+        else step
+        for step in child_plan
+    )
+
+
 def pipeline_instruction(
     child_plan: InProgressPhysicalPlan[PartitionT],
     pipeable_instruction: Instruction,
