@@ -402,6 +402,18 @@ class Series:
             raise TypeError(f"expected another Series but got {type(other)}")
         return Series._from_pyseries(self._series.arctan2(other._series))
 
+    def arctanh(self) -> Series:
+        """The elementwise inverse hyperbolic tangent of a numeric series"""
+        return Series._from_pyseries(self._series.arctanh())
+
+    def arccosh(self) -> Series:
+        """The elementwise inverse hyperbolic cosine of a numeric series"""
+        return Series._from_pyseries(self._series.arccosh())
+
+    def arcsinh(self) -> Series:
+        """The elementwise inverse hyperbolic sine of a numeric series"""
+        return Series._from_pyseries(self._series.arcsinh())
+
     def radians(self) -> Series:
         """The elementwise radians of a numeric series"""
         return Series._from_pyseries(self._series.radians())
@@ -499,6 +511,18 @@ class Series:
         assert self._series is not None and other._series is not None
         return Series._from_pyseries(self._series <= other._series)
 
+    def __lshift__(self, other: object) -> Series:
+        if not isinstance(other, Series):
+            raise TypeError(f"expected another Series but got {type(other)}")
+        assert self._series is not None and other._series is not None
+        return Series._from_pyseries(self._series << other._series)
+
+    def __rshift__(self, other: object) -> Series:
+        if not isinstance(other, Series):
+            raise TypeError(f"expected another Series but got {type(other)}")
+        assert self._series is not None and other._series is not None
+        return Series._from_pyseries(self._series >> other._series)
+
     def __invert__(self) -> Series:
         assert self._series is not None
         return Series._from_pyseries(self._series.__invert__())
@@ -541,6 +565,18 @@ class Series:
         assert self._series is not None
         return Series._from_pyseries(self._series.sum())
 
+    def shift_right(self, bits: Series) -> Series:
+        if not isinstance(bits, Series):
+            raise TypeError(f"expected another Series but got {type(bits)}")
+        assert self._series is not None and bits._series is not None
+        return Series._from_pyseries(self._series >> bits._series)
+
+    def shift_left(self, bits: Series) -> Series:
+        if not isinstance(bits, Series):
+            raise TypeError(f"expected another Series but got {type(bits)}")
+        assert self._series is not None and bits._series is not None
+        return Series._from_pyseries(self._series << bits._series)
+
     def if_else(self, if_true: object, if_false: object) -> Series:
         if not isinstance(if_true, Series):
             raise ValueError(f"expected another Series but got {type(if_true)}")
