@@ -6,6 +6,7 @@ import pathlib
 import random
 import time
 from collections.abc import Callable, Generator
+from functools import partial
 from typing import IO, TYPE_CHECKING, Any, Union
 from uuid import uuid4
 
@@ -682,14 +683,14 @@ def write_deltalake(
 
     data_files: list[AddAction] = []
 
-    # added to get_file_stats_from_metadata in deltalake v0.17.4: non-optional "num_indexed_cols" argument
+    # added to get_file_stats_from_metadata in deltalake v0.17.4: non-optional "num_indexed_cols" and "columns_to_collect_stats" arguments
     # https://github.com/delta-io/delta-rs/blob/353e08be0202c45334dcdceee65a8679f35de710/python/deltalake/writer.py#L725
     if parse(deltalake.__version__) < parse("0.17.4"):
         get_file_stats_from_metadata = deltalake.writer.get_file_stats_from_metadata
     else:
-
-        def get_file_stats_from_metadata(metadata):
-            deltalake.writer.get_file_stats_from_metadata(metadata, -1)
+        get_file_stats_from_metadata = partial(
+            deltalake.writer.get_file_stats_from_metadata, num_indexed_cols=-1, columns_to_collect_stats=None
+        )
 
     def file_visitor(written_file: Any) -> None:
         path, partition_values = get_partitions_from_path(written_file.path)
@@ -810,6 +811,7 @@ def _write_tabular_arrow_table(
     NUM_TRIES = 3
     JITTER_MS = 2_500
     MAX_BACKOFF_MS = 20_000
+    RETRY_ERRORS = ("InvalidPart", "curlCode: 28, Timeout was reached")
 
     for attempt in range(NUM_TRIES):
         try:
@@ -829,7 +831,7 @@ def _write_tabular_arrow_table(
             )
             break
         except OSError as e:
-            if "InvalidPart" not in str(e):
+            if all(err_str not in str(e) for err_str in RETRY_ERRORS):
                 raise
 
             if attempt == NUM_TRIES - 1:
