@@ -9,6 +9,7 @@ import pyarrow as pa
 import pytest
 
 from daft.datatype import DataType, ImageMode, TimeUnit
+from daft.exceptions import DaftCoreException
 from daft.series import Series
 from tests.series import ARROW_FLOAT_TYPES, ARROW_INT_TYPES, ARROW_STRING_TYPES
 
@@ -188,6 +189,28 @@ def test_series_cast_python_to_embedding(dtype) -> None:
     np.testing.assert_equal([np.asarray(arr, dtype=dtype.to_pandas_dtype()) for arr in data[:-1]], pydata[:-1])
 
 
+@pytest.mark.parametrize("dtype", ARROW_FLOAT_TYPES + ARROW_INT_TYPES)
+def test_series_cast_list_to_embedding(dtype) -> None:
+    data = [[1, 2, 3], [3, 2, 1], [4.1, 5.2, 6.3], None]
+    s = Series.from_pylist(data, pyobj="disallow")
+
+    target_dtype = DataType.embedding(DataType.from_arrow_type(dtype), 3)
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+    assert len(t) == len(data)
+
+    assert t.list.lengths().to_pylist() == [3, 3, 3, None]
+
+    pydata = t.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(
+        [np.asarray(arr, dtype=dtype.to_pandas_dtype()) for arr in data[:-1]],
+        pydata[:-1],
+    )
+
+
 def test_series_cast_numpy_to_image() -> None:
     data = [
         np.arange(12, dtype=np.uint8).reshape((2, 2, 3)),
@@ -791,3 +814,20 @@ def test_cast_timestamp_to_time_unsupported_timeunit(timeunit):
     input = Series.from_pylist([datetime(2022, 1, 6, 12, 34, 56, 78)])
     with pytest.raises(ValueError):
         input.cast(DataType.time(timeunit))
+
+
+def test_cast_binary_to_fixed_size_binary():
+    data = [b"abc", b"def", None, b"bcd", None]
+
+    input = Series.from_pylist(data)
+    assert input.datatype() == DataType.binary()
+    casted = input.cast(DataType.fixed_size_binary(3))
+    assert casted.to_pylist() == [b"abc", b"def", None, b"bcd", None]
+
+
+def test_cast_binary_to_fixed_size_binary_fails_with_variable_lengths():
+    data = [b"abc", b"def", None, b"bcd", None, b"long"]
+
+    input = Series.from_pylist(data)
+    with pytest.raises(DaftCoreException):
+        input.cast(DataType.fixed_size_binary(3))
