@@ -125,17 +125,22 @@ def test_series_if_else_bool(
     "if_false_length",
     [1, 3],
 )
+@pytest.mark.parametrize(
+    "type, expected_type", [(pa.binary(), DataType.binary()), (pa.binary(1), DataType.fixed_size_binary(1))]
+)
 def test_series_if_else_binary(
     if_true_value,
     if_false_value,
     if_true_length,
     if_false_length,
+    type,
+    expected_type,
 ) -> None:
-    if_true_series = Series.from_arrow(pa.array([if_true_value] * if_true_length, type=pa.binary()))
-    if_false_series = Series.from_arrow(pa.array([if_false_value] * if_false_length, type=pa.binary()))
+    if_true_series = Series.from_arrow(pa.array([if_true_value] * if_true_length, type=type))
+    if_false_series = Series.from_arrow(pa.array([if_false_value] * if_false_length, type=type))
     predicate_series = Series.from_arrow(pa.array([True, False, None]))
     result = predicate_series.if_else(if_true_series, if_false_series)
-    assert result.datatype() == DataType.binary()
+    assert result.datatype() == expected_type
     assert result.to_pylist() == [if_true_value, if_false_value, None]
 
 
@@ -423,29 +428,25 @@ def test_series_if_else_extension_type(uuid_ext_type, if_true_storage, if_false_
         (
             np.arange(16).reshape((4, 2, 2)),
             np.arange(16, 32).reshape((4, 2, 2)),
-            np.array(
-                [[[0, 1], [2, 3]], [[20, 21], [22, 23]], [[np.nan, np.nan], [np.nan, np.nan]], [[12, 13], [14, 15]]]
-            ),
+            np.array([[[0, 1], [2, 3]], [[20, 21], [22, 23]], [[12, 13], [14, 15]]]),
         ),
         # Broadcast left
         (
             np.arange(4).reshape((1, 2, 2)),
             np.arange(16, 32).reshape((4, 2, 2)),
-            np.array([[[0, 1], [2, 3]], [[20, 21], [22, 23]], [[np.nan, np.nan], [np.nan, np.nan]], [[0, 1], [2, 3]]]),
+            np.array([[[0, 1], [2, 3]], [[20, 21], [22, 23]], [[0, 1], [2, 3]]]),
         ),
         # Broadcast right
         (
             np.arange(16).reshape((4, 2, 2)),
             np.arange(16, 20).reshape((1, 2, 2)),
-            np.array(
-                [[[0, 1], [2, 3]], [[16, 17], [18, 19]], [[np.nan, np.nan], [np.nan, np.nan]], [[12, 13], [14, 15]]]
-            ),
+            np.array([[[0, 1], [2, 3]], [[16, 17], [18, 19]], [[12, 13], [14, 15]]]),
         ),
         # Broadcast both
         (
             np.arange(4).reshape((1, 2, 2)),
             np.arange(16, 20).reshape((1, 2, 2)),
-            np.array([[[0, 1], [2, 3]], [[16, 17], [18, 19]], [[np.nan, np.nan], [np.nan, np.nan]], [[0, 1], [2, 3]]]),
+            np.array([[[0, 1], [2, 3]], [[16, 17], [18, 19]], [[0, 1], [2, 3]]]),
         ),
     ],
 )
@@ -462,7 +463,12 @@ def test_series_if_else_canonical_tensor_extension_type(if_true, if_false, expec
         DataType.from_arrow_type(if_true_arrow.type.storage_type.value_type), (2, 2)
     )
     result_arrow = result.to_arrow()
-    np.testing.assert_equal(result_arrow.to_numpy_ndarray(), expected)
+
+    # null element conversion to numpy is not well defined in pyarrow and changes between releases
+    # so this is a workaround to ensure our tests pass regardless of the pyarrow version
+    assert not result_arrow[2].is_valid
+    result_array_filtered = result_arrow.filter(pa.array([True, True, False, True]))
+    np.testing.assert_equal(result_array_filtered.to_numpy_ndarray(), expected)
 
 
 @pytest.mark.parametrize(
@@ -553,12 +559,16 @@ def test_series_if_else_predicate_broadcast_bools(predicate_value, expected_resu
     ["predicate_value", "expected_results"],
     [(True, [b"Y", b"Y", b"Y"]), (False, [b"N", b"N", b"N"]), (None, [None, None, None])],
 )
-def test_series_if_else_predicate_broadcast_binary(predicate_value, expected_results) -> None:
-    if_true_series = Series.from_arrow(pa.array([b"Y", b"Y", b"Y"], type=pa.binary()))
-    if_false_series = Series.from_arrow(pa.array([b"N", b"N", b"N"], type=pa.binary()))
+@pytest.mark.parametrize(
+    "type, result_type",
+    [(pa.binary(), DataType.binary()), (pa.binary(1), DataType.fixed_size_binary(1))],
+)
+def test_series_if_else_predicate_broadcast_binary(predicate_value, expected_results, type, result_type) -> None:
+    if_true_series = Series.from_arrow(pa.array([b"Y", b"Y", b"Y"], type=type))
+    if_false_series = Series.from_arrow(pa.array([b"N", b"N", b"N"], type=type))
     predicate_series = Series.from_arrow(pa.array([predicate_value], type=pa.bool_()))
     result = predicate_series.if_else(if_true_series, if_false_series)
-    assert result.datatype() == DataType.binary()
+    assert result.datatype() == result_type
     assert result.to_pylist() == expected_results
 
 
